****************************************************************************************
* PROGRAMME: MAIN PROGRAMME
* This programme runs all the programmes necessary to generate the 
* results in the paper. 
* STEP 1: Importing the data
* STEP 2: Computing the implicit subsidy.
* STEP 3: Generating the results for the standard model in Table 3 and Table 4
* STEP 4: Generating the results for the augmented model in Table 3 and Table 4
* STEP 5: Generating the results for the non-TBTF banks model in Table 3 and Table 4
* STEP 6: Generating the summary statistics in Table B.1 and B.2
* STEP 7: Generating the summary statistics in Table 1 and 2

* nb: the data directory of each programme will need to be appropriately set.
****************************************************************************************

****************************************************************************************
* STEP 1: Importing the data
****************************************************************************************
* Bank balance sheet, income statement and ratings data (S&P Cap IQ, Bloomberg, published accounts, Moodys)
clear
* cd to put in relevant directory here
insheet using "Bank_data_import.csv"
save "Bank_data_import.dta", replace

* Bond indices data (Merrill Lynch)
clear
* cd to put in relevant directory here
insheet using "Bond_data_import.csv"
save "Bond_data_import.dta", replace

* Macro data (primarily IMF IFS, IMF WEO, World Bank, Barth et al. 2004, 2008)
clear
* cd to put in relevant directory here
insheet using "Macro_data_import.csv"
save "Macro_data_import.dta", replace

*** START LOG
log using "Scale_economies_results.log", replace

****************************************************************************************
* STEP 2: Computing the implicit subsidy.
****************************************************************************************
* Preparing the bond data, turning AAA, AA, A, BBB ratings scale to a Moodys rating scale
* cd to put in relevant directory here
run "1.Bond_data_organisation_code.do"
* Computing the implicit subsidy
run "2.Implicit_subsidy_calculation_code.do"

****************************************************************************************
* STEP 3: Generating the results for the standard model in Table 3 and Table 4
****************************************************************************************
* Merging the bank panel data, macro data and implicit subsidy
run "3.Data_merger_code.do"

* TABLE 3, STANDARD MODEL
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.a.i.Scale_economies_master, standard model, 3 inputs.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL A: Includes non-performing loans, n, as a measure of ex post asset quality, as an additional netput
foreach model of newlist SUR_n {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_n {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL B: Includes financial equity capital, k, as an input rather than a netput
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count ec_`model' mean ec_`model' mean se_ec_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count ec_`model' mean ec_`model' mean se_mean_ec_`model')
}

* TABLE 4, STANDARD MODEL, PANEL F: Excludes observations from the year 2009
foreach model of newlist SUR_X09 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_X09 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL G: Includes observations from the period 2001 to 2007 
foreach model of newlist SUR_07 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_07 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL J: Specifies the cost function using a Fourier Flexible functional form
foreach model of newlist SUR_FF  {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_FF {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL C: Includes physical capital, x_p, as a netput rather than an input
run "4.b.i.Cost_fn_variables_contraints, 2 inputs, fixed assets as a netput, no subsidy adjustment.do"
run "5.b.i.Scale_economies_master, standard model, 2 inputs, fixed assets as a netput.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL D: Measures the price of physical capital alternatively as w_p=occupancy expenses/fixed assets 
run "4.c.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment, w_p OE on FA.do"
run "5.c.i.Scale_economies_master, standard model, w_p OE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL E: Measures the price of physical capital alternatively as w_p=other NIE/fixed assets 
run "4.d.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment, w_p ONIE on FA.do"
run "5.d.i.Scale_economies_master, standard model, w_p ONIE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL H: Excludes observations for Chinese banks 
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.e.i.Scale_economies_master, standard model, Chinese banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, STANDARD MODEL, PANEL I: Excludes observations for U.S. banks
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.f.i.Scale_economies_master, standard model, US banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}


****************************************************************************************
* STEP 4: Generating the results for the augmented model in Table 3 and Table 4
****************************************************************************************
* TABLE 3, AUGMENTED MODEL
run "4.a.ii.Cost_fn_variables_contraints, 3 inputs, subsidy adjustment.do"
run "5.a.ii.Scale_economies_master, augmented model, 3 inputs.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL A: Includes non-performing loans, n, as a measure of ex post asset quality, as an additional netput
foreach model of newlist SUR_n {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_n {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL B: Includes financial equity capital, k, as an input rather than a netput
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count ec_`model' mean ec_`model' mean se_ec_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count ec_`model' mean ec_`model' mean se_mean_ec_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL F: Excludes observations from the year 2009
foreach model of newlist SUR_X09 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_X09 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL G: Includes observations from the period 2001 to 2007 
foreach model of newlist SUR_07 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_07 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL J: Specifies the cost function using a Fourier Flexible functional form
foreach model of newlist SUR_FF  {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR_FF {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL C: Includes physical capital, x_p, as a netput rather than an input
run "4.b.ii.Cost_fn_variables_contraints, 2 inputs, fixed assets as a netput, subsidy adjustment.do"
run "5.b.ii.Scale_economies_master, augmented model, 2 inputs, fixed assets as a netput.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL D: Measures the price of physical capital alternatively as w_p=occupancy expenses/fixed assets 
run "4.c.ii.Cost_fn_variables_contraints, 3 inputs, subsidy adjustment, w_p OE on FA.do"
run "5.c.ii.Scale_economies_master, augmented model, w_p OE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL E: Measures the price of physical capital alternatively as w_p=other NIE/fixed assets 
run "4.d.ii.Cost_fn_variables_contraints, 3 inputs, subsidy adjustment, w_p ONIE on FA.do"
run "5.d.ii.Scale_economies_master, augmented model, w_p ONIE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL H: Excludes observations for Chinese banks 
run "4.a.ii.Cost_fn_variables_contraints, 3 inputs, subsidy adjustment.do"
run "5.e.ii.Scale_economies_master, augmented model, Chinese banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

* TABLE 4, AUGMENTED MODEL, PANEL I: Excludes observations for U.S. banks
run "4.a.ii.Cost_fn_variables_contraints, 3 inputs, subsidy adjustment.do"
run "5.f.ii.Scale_economies_master, augmented model, US banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model' mean cf_`model' mean se_`model'_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model' mean cf_`model' mean se_mean_cf_`model')
}

****************************************************************************************
* STEP 5: Generating the results based on estimation of the non-TBTF banks in Table 3 and Table 4
****************************************************************************************
* TABLE 3, ESTIMATION FOR NON-TBTF BANKS
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.a.iii.Scale_economies_master, non TBTF banks, 3 inputs.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL A: Includes non-performing loans, n, as a measure of ex post asset quality, as an additional netput
foreach model of newlist SUR_n {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR_n {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL B: Includes financial equity capital, k, as an input rather than a netput
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count ec_`model'_ns mean ec_`model'_ns mean se_ec_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count ec_`model'_ns mean ec_`model'_ns mean se_mean_ec_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL F: Excludes observations from the year 2009
foreach model of newlist SUR_X09 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR_X09 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL G: Includes observations from the period 2001 to 2007 
foreach model of newlist SUR_07 {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR_07 {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL J: Specifies the cost function using a Fourier Flexible functional form
foreach model of newlist SUR_FF  {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR_FF {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL C: Includes physical capital, x_p, as a netput rather than an input
run "4.b.i.Cost_fn_variables_contraints, 2 inputs, fixed assets as a netput, no subsidy adjustment.do"
run "5.b.iii.Scale_economies_master, non TBTF banks, 2 inputs, fixed assets as a netput.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL D: Measures the price of physical capital alternatively as w_p=occupancy expenses/fixed assets 
run "4.c.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment, w_p OE on FA.do"
run "5.c.iii.Scale_economies_master, non TBTF banks, w_p OE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL E: Measures the price of physical capital alternatively as w_p=other NIE/fixed assets 
run "4.d.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment, w_p ONIE on FA.do"
run "5.d.iii.Scale_economies_master, non TBTF banks, w_p ONIE on FA.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL H: Excludes observations for Chinese banks 
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.e.iii.Scale_economies_master, non TBTF banks, Chinese banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

* TABLE 4, ESTIMATION FOR NON-TBTF BANKS, PANEL I: Excludes observations for U.S. banks
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.f.iii.Scale_economies_master, non TBTF banks, US banks country robustness.do"
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}

****************************************************************************************
* STEP 6: Generating the summary statistics in Table B.1 and B.2
* STEP 7: Generating the summary statistics in Table 1 and 2
****************************************************************************************
run "6.Summary statistics.do"

*** SUMMARY STATISTICS FOR TABLE B.2 and TABLE B.3: MEAN AND STD DEV, 2001-2010
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table _est_SUR if date > 2000, c(mean `var' sd `var')
}
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table region2 if date > 2000 & _est_SUR == 1, c(mean `var' sd `var')
}
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table assetbuckets if date > 2000 & _est_SUR == 1, c(mean `var' sd `var')
}

*** SUMMARY STATISTICS FOR TABLE 1: THE IMPACT OF THE IMPLICIY SUBSIDY ON THE PRICE OF DEBT
*** SUMMARY STATISTICS FOR TABLE 2: CHARACTERISTICS OF THE IMPLICIT SUBSIDY

table _est_SUR if date > 2000, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table assetbuckets if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table region2      if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table date         if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)

table implicit_subsidy if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction)
table region2      if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)
table assetbuckets if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)
table date if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)


* OWN AND CROSS-PRICE ELASTICITIES
run "4.a.i.Cost_fn_variables_contraints, 3 inputs, no subsidy adjustment.do"
run "5.a.i.Scale_economies_master, standard model, 3 inputs.do"
run "7.Cross elasticities, vale of mean.do"
table _est_SUR if date > 2000 & _est_SUR == 1, c(count G_dd_subsidy mean G_ld_subsidy mean G_pd_subsidy mean G_dd_subsidy)
table _est_SUR if date > 2000 & _est_SUR == 1, c(count total_cost_delta mean total_cost_delta)

log close 

