*******************************************************************
* PROGRAMME: BOND DATA ORGANISATION
* This programme organises the bond data to be used to compute the
* implicit subsidy.
* The main steps in the programme are:
* 1. Taking yearly averages for each region and rating
* 2. Converting the bond data indice ratingsscale to a Moodys 
* rating scale, based on Table A.3 of the paper
*******************************************************************

*** IMPORT DATA
clear
set more off
* cd to put in relevant directory here
use "Bond_data_import.dta"

*** New variables for rating, ordered by rating scale
gen rating_rank = "Empty"
replace rating_rank = "1.AAA"	if rating == "AAA"
replace rating_rank = "2.AA" 	if rating == "AA"
replace rating_rank = "3.A" 	if rating == "A"
replace rating_rank = "4.BBB" 	if rating == "BBB"
replace rating_rank = "5.BB" 	if rating == "BB"
replace rating_rank = "6.B" 	if rating == "B"
replace rating_rank = "7.C" 	if rating == "C"

*** Taking the average of yield to maturity, for each region, year and rating
sort regionyear rating
by regionyear rating: egen avg_yield = mean(yieldtomaturityconv) 


*** Keeping only one observation for the average of yield to maturity, for each region, year and rating
bysort regionyear rating: gen t = _n
drop if t > 1
drop yieldtomaturityconv t

*** Converting to Moody's scale
gen rating_rank_num = 0
replace rating_rank_num = 1		if rating == "AAA"
replace rating_rank_num = 2 	if rating == "AA"
replace rating_rank_num = 3 	if rating == "A"
replace rating_rank_num = 4 	if rating == "BBB"
replace rating_rank_num = 5 	if rating == "BB"
replace rating_rank_num = 6 	if rating == "B"
replace rating_rank_num = 7 	if rating == "C"

keep avg_yield regionyear rating_rank_num
reshape wide avg_yield, i(regionyear)  j(rating_rank_num) 

* Aaa
gen Moodys1 = (avg_yield1 + avg_yield2)/2
* Aa1
gen Moodys2 = (avg_yield1 + avg_yield2)/2
* Aa2
gen Moodys3 = avg_yield2
* Aa3
gen Moodys4 = (2/3)*avg_yield2 + (1/3)*avg_yield3
* A1
gen Moodys5 = (1/3)*avg_yield2 + (2/3)*avg_yield3
* A2
gen Moodys6 = avg_yield3
* A3
gen Moodys7 = (2/3)*avg_yield3 + (1/3)*avg_yield4
* Baa1
gen Moodys8 = (1/3)*avg_yield3 + (2/3)*avg_yield4
* Baa2
gen Moodys10 = avg_yield4 
* Baa1-Baa2
gen Moodys9 = (Moodys8 + Moodys10)/2
* Baa3
gen Moodys11 = (2/3)*avg_yield4 + (1/3)*avg_yield5
* Ba1
gen Moodys13 = (1/3)*avg_yield4 + (2/3)*avg_yield5
* Baa3-Ba1
gen Moodys12 = (Moodys11 + Moodys13)/2
* Ba2
gen Moodys14 = avg_yield5
* Ba3
gen Moodys15 = (avg_yield5 + avg_yield6)/2 
* B1-B3
gen Moodys16 = avg_yield6
* Caa1-Ca
gen Moodys17 = avg_yield7

drop avg_yield1-avg_yield7

reshape long Moodys, i(regionyear) j(rating_rank)

*** Giving the data sensible names
gen Moodys_rating = "X"
replace Moodys_rating = "Aaa"		if rating_rank == 1
replace Moodys_rating = "Aa1"		if rating_rank == 2
replace Moodys_rating = "Aa2"		if rating_rank == 3
replace Moodys_rating = "Aa3"		if rating_rank == 4
replace Moodys_rating = "A1"		if rating_rank == 5
replace Moodys_rating = "A2"		if rating_rank == 6
replace Moodys_rating = "A3"		if rating_rank == 7
replace Moodys_rating = "Baa1"		if rating_rank == 8
replace Moodys_rating = "Baa1-Baa2"	if rating_rank == 9
replace Moodys_rating = "Baa2"		if rating_rank == 10
replace Moodys_rating = "Baa3"		if rating_rank == 11
replace Moodys_rating = "Baa3-Ba1"	if rating_rank == 12
replace Moodys_rating = "Ba1"		if rating_rank == 13
replace Moodys_rating = "Ba2"		if rating_rank == 14
replace Moodys_rating = "Ba3"		if rating_rank == 15
replace Moodys_rating = "B1-B3"		if rating_rank == 16
replace Moodys_rating = "Caa1-Ca"	if rating_rank == 17
 
rename Moodys yield

*** Notch rank
gen rating_notch = 0
replace rating_notch = 1	if rating_rank == 1 
replace rating_notch = 2	if rating_rank == 2 
replace rating_notch = 3	if rating_rank == 3 
replace rating_notch = 4	if rating_rank == 4 
replace rating_notch = 5	if rating_rank == 5 
replace rating_notch = 6	if rating_rank == 6 
replace rating_notch = 7	if rating_rank == 7 
replace rating_notch = 8	if rating_rank == 8 
replace rating_notch = 8.5	if rating_rank == 9 
replace rating_notch = 9	if rating_rank == 10 
replace rating_notch = 10	if rating_rank == 11 
replace rating_notch = 10.5	if rating_rank == 12 
replace rating_notch = 11	if rating_rank == 13 
replace rating_notch = 12	if rating_rank == 14 
replace rating_notch = 13	if rating_rank == 15
replace rating_notch = 14	if rating_rank == 16 
replace rating_notch = 15	if rating_rank == 17 

gen RegionYear_SUR = regionyear + Moodys_rating
gen RegionYear_BFSR = regionyear + Moodys_rating

save "Bond_data_concise.dta", replace
