*******************************************************************
* PROGRAMME: BOND DATA ORGANISATION
* This programme organises the bond data to be used to compute the
* implicit subsidy.
* The main steps in the programme are:
* 1. Taking yearly averages for each region and rating
* 2. Converting the bond data indice ratingsscale to a Moodys 
* rating scale, based on Table A.3 of the paper
*******************************************************************

*** IMPORT DATA
clear
set more off
* cd to put in relevant directory here
use "Bank_data_import.dta"

keep order -date date total_deposits total_liab bfsr - derivative_liabilities

gen rating_sensitive_liab = total_liab - total_deposits - derivative_liabilities
replace rating_sensitive_liab = 0 if rating_sensitive_liab < 0

gen RegionYear_SUR = regionyear + sur
gen RegionYear_BFSR = regionyear + bfsr_converted 

joinby RegionYear_SUR using "Bond_data_concise.dta", unmatched(master)
rename yield SUR_yield
drop _merge Moodys_rating rating_notch 

joinby RegionYear_BFSR using "Bond_data_concise.dta", unmatched(master)
rename yield BFSR_yield
drop _merge Moodys_rating rating_notch 

*** BFSR notch rank
gen BFSR_rating_notch = 0
replace BFSR_rating_notch = 1 	if bfsr_converted == "Aaa"
replace BFSR_rating_notch = 2 	if bfsr_converted == "Aa1"
replace BFSR_rating_notch = 3 	if bfsr_converted == "Aa2"
replace BFSR_rating_notch = 4 	if bfsr_converted == "Aa3"
replace BFSR_rating_notch = 5 	if bfsr_converted == "A1"
replace BFSR_rating_notch = 6 	if bfsr_converted == "A2"
replace BFSR_rating_notch = 7 	if bfsr_converted == "A3"
replace BFSR_rating_notch = 8 	if bfsr_converted == "Baa1"
replace BFSR_rating_notch = 8.5 if bfsr_converted == "Baa1-Baa2"
replace BFSR_rating_notch = 9 	if bfsr_converted == "Baa2"
replace BFSR_rating_notch = 10 	if bfsr_converted == "Baa3"
replace BFSR_rating_notch = 10.5 if bfsr_converted == "Baa3-Ba1"
replace BFSR_rating_notch = 11 	if bfsr_converted == "Ba1"
replace BFSR_rating_notch = 12 	if bfsr_converted == "Ba2"
replace BFSR_rating_notch = 13 	if bfsr_converted == "Ba3"
replace BFSR_rating_notch = 14 	if bfsr_converted == "B1-B3"
replace BFSR_rating_notch = 15 	if bfsr_converted == "Caa1-Ca"
 
*** SUR notch rank
gen SUR_rating_notch = 0
replace SUR_rating_notch = 1 	if sur == "Aaa"
replace SUR_rating_notch = 2 	if sur == "Aa1"
replace SUR_rating_notch = 3 	if sur == "Aa2"
replace SUR_rating_notch = 4 	if sur == "Aa3"
replace SUR_rating_notch = 5 	if sur == "A1"
replace SUR_rating_notch = 6 	if sur == "A2"
replace SUR_rating_notch = 7 	if sur == "A3"
replace SUR_rating_notch = 8 	if sur == "Baa1"
replace SUR_rating_notch = 8.5  if sur == "Baa1-Baa2"
replace SUR_rating_notch = 9 	if sur == "Baa2"
replace SUR_rating_notch = 10 	if sur == "Baa3"
replace SUR_rating_notch = 10.5 if sur == "Baa3-Ba1"
replace SUR_rating_notch = 11 	if sur == "Ba1"
replace SUR_rating_notch = 12 	if sur == "Ba2"
replace SUR_rating_notch = 13 	if sur == "Ba3"
replace SUR_rating_notch = 14 	if sur == "B1-B3"
replace SUR_rating_notch = 15 	if sur == "Caa1-Ca"

*** COMPUTING THE IMPLICIT SUBSIDY
gen implicit_subsidy = 0
replace implicit_subsidy = 1 if BFSR_rating_notch > SUR_rating_notch & BFSR_rating_notch != 0 & SUR_rating_notch != 0
label var implicit_subsidy "Implicit subsidy indicator"

gen implicit_subsidy2 = BFSR_rating_notch - SUR_rating_notch
replace implicit_subsidy2 = 0 if implicit_subsidy2 < 0 
label var implicit_subsidy2 "Ratings uplift"

gen implicit_subsidy4 = ((BFSR_yield-SUR_yield)/100)*rating_sensitive_liab
replace implicit_subsidy4 = 0 if implicit_subsidy4 == . | implicit_subsidy4 < 0 | implicit_subsidy == 0 
label var implicit_subsidy4 "Implicit subsidy value"

drop total_deposits-total_liab RegionYear_SUR-SUR_rating_notch

save "Implicit_subsidy_import.dta", replace
