*******************************************************************
* PROGRAMME: DATA IMPORT
*******************************************************************
*** IMPORT DATA
clear
set more off
* cd to put in relevant directory here
use "Bank_data_import.dta"

*******************************************************************
*** REMOVING CENTRAL BANKS
drop if central_bank == 1

*******************************************************************
*** MERGING MACRO DATA
joinby country date using "Macro_data_import.dta", unmatched(master)
drop _merge

*******************************************************************
*** MERGING THE IMPLICIT SUBSIDY
*insheet using "Implicit_subsidy_import.csv"
*save "Implicit_subsidy_import.dta", replace

*** Includes all updates
joinby company date using "Implicit_subsidy_import.dta", unmatched(master)
drop _merge
foreach var of varlist implicit_subsidy-implicit_subsidy4 {
replace `var'=0 if `var'==.
}

*******************************************************************
*** INFLATION ADJUSTING THE DATA
sort company date
foreach var of varlist total_assets-non_performing_loans {
replace `var' = `var'*inflation_adjustment_home_2010
}

*******************************************************************
*** GENERATING USEFUL BANK ID AND TIME VARIABLES
*** BANK ID VARIABLE
sort date company 
bysort date: gen company_id = _n

*** ASSET BUCKET VARIABLES
gsort company -date
gen assetbuckets= "1 <$100bn"
replace assetbuckets = "1 $100bn-$500bn" if total_assets > 100000
replace assetbuckets = "2 $100bn-$500bn" if total_assets > 100000
replace assetbuckets = "3 $500bn-$1tn"   if total_assets > 500000
replace assetbuckets = "4 $1tn-$2tn"     if total_assets > 1000000
replace assetbuckets = "5 >$2tn"         if total_assets > 2000000

*******************************************************************
*** SAVING THE DATA
sort order
* cd to put in relevant directory here
save "Bank_macro_data.dta", replace

