*******************************************************************
* PROGRAMME: COST FUNCTION ESTIMATION AND SCALE ECON COMPUTATION
*******************************************************************
*** PROGRAMME STRUCTURE:
* 1: IMPORT DATA
* 2: REGRESSIONS OF THE TRANSLOG COST FUNCTION
* 3: COMPUTING SCALE ECONOMIES FOR EACH BANK
* 4: COMPUTING THE VARIANCE OF SCALE ECONOMIES, DELTA METHOD

*******************************************************************
*** 1: IMPORT DATA
clear
set more off
* cd to put in relevant directory here
use "Cost_fn_variables_no_subsidy.dta"

sort company date 
xtset company_id date

set matsize 1000
set emptycells drop

*******************************************************************
*** DROPPING REPEAT BANKS
* Banco Espirito Santo SA is a subsidiary of Esprito Santo Financial Group
drop if company == "Banco Espirito Santo SA"
* Banco Santander (Brasil) S.A. is a subsidiary of Banco Santander in Brasil
drop if company == "Banco Santander (Brasil) S.A."
* Citibank Japan Ltd. is a subsidiary of Citigroup, Inc.
drop if company == "Citibank Japan Ltd."

*** DROPPING BROKERS (i.e. banks classified as "Investment Banking and Brokerage" in Capital IQ. They do not do retail banking)
drop if company == "The Goldman Sachs Group, Inc."
drop if company == "Morgan Stanley"
drop if company == "Nomura Holdings Inc."
drop if company == "Daiwa Securities Group Inc."
drop if company == "Macquarie Group, Ltd."
drop if company == "ICAP plc"
drop if company == "Mediobanca S.p.A." 
drop if company == "Queensland Treasury Corp."
drop if company == "Charles Schwab Corp."

*******************************************************************
*** 2: REGRESSIONS OF THE COST FUNCTION 
*** CROSS-EQUATION CONSTRAINTS FOR S_p
constraint 1  [cons_ln_total_cost]cons_ln_w_p 		 	= [S_p]_cons
constraint 2  [cons_ln_total_cost]cons_H_ln_w_p_ln_w_p  = [S_p]cons_ln_w_p
constraint 3  [cons_ln_total_cost]cons_H_ln_w_p_ln_w_l  = [S_p]cons_ln_w_l
constraint 4  [cons_ln_total_cost]cons_y_1_ln_w_p 	 	= [S_p]ln_y_1
constraint 5  [cons_ln_total_cost]cons_y_2_ln_w_p 	 	= [S_p]ln_y_2
constraint 6  [cons_ln_total_cost]cons_y_3_ln_w_p  	 	= [S_p]ln_y_3
constraint 7  [cons_ln_total_cost]cons_y_4_ln_w_p 	 	= [S_p]ln_y_4
constraint 8  [cons_ln_total_cost]cons_y_5_ln_w_p 	 	= [S_p]ln_y_5
constraint 9  [cons_ln_total_cost]cons_ln_w_p_ln_k 	 	= [S_p]ln_k
*** CROSS-EQUATION CONSTRAINTS FOR S_l
constraint 10 [cons_ln_total_cost]cons_ln_w_l 		 	= [S_l]_cons
constraint 11 [cons_ln_total_cost]cons_H_ln_w_l_ln_w_l 	= [S_l]cons_ln_w_l
constraint 12 [cons_ln_total_cost]cons_H_ln_w_p_ln_w_l 	= [S_l]cons_ln_w_p
constraint 13 [cons_ln_total_cost]cons_y_1_ln_w_l 	 	= [S_l]ln_y_1
constraint 14 [cons_ln_total_cost]cons_y_2_ln_w_l 	 	= [S_l]ln_y_2
constraint 15 [cons_ln_total_cost]cons_y_3_ln_w_l 	 	= [S_l]ln_y_3
constraint 16 [cons_ln_total_cost]cons_y_4_ln_w_l 	 	= [S_l]ln_y_4
constraint 17 [cons_ln_total_cost]cons_y_5_ln_w_l 	 	= [S_l]ln_y_5
constraint 18 [cons_ln_total_cost]cons_ln_w_l_ln_k 	 	= [S_l]ln_k

*** ADDITIONAL CROSS_EQUAION CONSTRAINTS THAT ARE RELEVANT WHEN MODELLING RISK TAKING
constraint 19 [cons_ln_total_cost]cons_ln_w_p_ln_n   	= [S_p]ln_n
constraint 20 [cons_ln_total_cost]cons_ln_w_l_ln_n 	 	= [S_l]ln_n

*******************************************************************
*** 2b: ORGANISATION OF RELEVANT VARIABLES FOR THE COST FUNCTION 
global macro_controls  	gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration
global bank_fe  		i.company_id
global time_fe  		i.date

global lny 				ln_y_1-ln_y_5 
global lnylny  			H_ln_y_1_ln_y_1-cons_H_ln_y_4_ln_y_5 
global lnw  			cons_ln_w_p cons_ln_w_l 
global lnwlnw  			cons_H_ln_w_p_ln_w_p-cons_H_ln_w_p_ln_w_l 
global lnk  			ln_k 
global lnn  			ln_n 
global lnklnk  			H_ln_k_ln_k 
global lnnlnn  			H_ln_n_ln_n 
global lnklnn  			ln_k_ln_n 
global lnylnw  			cons_y_1_ln_w_p-cons_y_5_ln_w_l 
global lnwlnk  			cons_ln_w_p_ln_k cons_ln_w_l_ln_k
global lnwlnn  			cons_ln_w_p_ln_n cons_ln_w_l_ln_n 
global lnylnk  			ln_y_1_ln_k-ln_y_5_ln_k 
global lnylnn  			ln_y_1_ln_n-ln_y_5_ln_n 

global trig_terms  		cos_q1-sin_q45

*******************************************************************
*** 2c: REGRESSIONS OF THE COST FUNCTION 
*** TRANSLOG SPECIFICATION
*** NO MODELLING OF RISK
*** MACRO CONTROLS, NO TIME DUMMIES 
*local translog 		cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnw $lnwlnw $lnk $lnklnk $lnwlnk $bank_fe $macro_controls $time_fe
local translog 		cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnw $lnwlnw $lnk $lnklnk $lnwlnk $bank_fe $macro_controls

* FULL PERIOD
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000, c(1-18)
estimates store SUR
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & implicit_subsidy == 0, c(1-18) 
estimates store SUR_ns
* PRE CRISIS
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & date <2008, c(1-18)
estimates store SUR_07
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & date <2008 & implicit_subsidy == 0, c(1-18)  
estimates store SUR_07_ns
* EXCL. 2009
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & date != 2009, c(1-18)
estimates store SUR_X09
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & date != 2009 & implicit_subsidy == 0, c(1-18)  
estimates store SUR_X09_ns

*******************************************************************
*** 2d: REGRESSIONS OF THE COST FUNCTION 
*** FOURIER FLEXIBLE FUNCTION FORM
*** NO MODELLING OF RISK
*** MACRO CONTROLS, NO TIME DUMMIES 
*local fourier 			cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnw $lnwlnw $lnk $lnklnk $lnwlnk $trig_terms $bank_fe $macro_controls $time_fe
local fourier 			cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnw $lnwlnw $lnk $lnklnk $lnwlnk $trig_terms $bank_fe $macro_controls

* FULL PERIOD
sureg (`fourier') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000, c(1-18)
estimates store SUR_FF
sureg (`fourier') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & implicit_subsidy == 0, c(1-18) 
estimates store SUR_FF_ns

*******************************************************************
*** 2f: REGRESSIONS OF THE COST FUNCTION 
*** TRANSLOG SPECIFICATION
*** MODELLING OF RISK
*** MACRO CONTROLS, NO TIME DUMMIES 
local translog 		cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnylnn $lnw $lnwlnw $lnk $lnklnk $lnwlnk $lnn $lnnlnn $lnwlnn $lnklnn $bank_fe $macro_controls

* FULL PERIOD
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k ln_n) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k ln_n) if date > 2000, c(1-20)
estimates store SUR_n
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k ln_n) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k ln_n) if date > 2000 & implicit_subsidy == 0, c(1-20) 
estimates store SUR_n_ns

local translog 		cons_ln_total_cost $lny $lnylny $lnylnw $lnylnk $lnw $lnwlnw $lnk $lnklnk $lnwlnk $bank_fe $macro_controls
sureg (`translog') (S_p cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) (S_l cons_ln_w_p cons_ln_w_l ln_y_1-ln_y_5 ln_k) if date > 2000 & implicit_subsidy == 0, c(1-18)  
estimates store SUR_ns

*******************************************************************
* 3: SCALE ECONOMIES CALCULATIONS

sort company date 
xtset company_id date

*******************************************************************
*** 3a: COMPUTING SCALE ECONOMIES FOR EACH BANK
*** TRANSLOG SPECIFICATION
*** NO MODELLING OF RISK
sort company date 
xtset company_id date
foreach model of newlist SUR_ns SUR_07_ns SUR_X09_ns {
est restore `model'
bysort company date: gen a = _b[ln_y_1] + _b[ln_y_2] + _b[ln_y_3] + _b[ln_y_4] + _b[ln_y_5]
bysort company date: gen b_y1 = ln_y_1 * (_b[H_ln_y_1_ln_y_1] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_1_ln_y_5])
bysort company date: gen b_y2 = ln_y_2 * (_b[H_ln_y_2_ln_y_2] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_2_ln_y_5])
bysort company date: gen b_y3 = ln_y_3 * (_b[H_ln_y_3_ln_y_3] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_3_ln_y_5])
bysort company date: gen b_y4 = ln_y_4 * (_b[H_ln_y_4_ln_y_4] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b_y5 = ln_y_5 * (_b[H_ln_y_5_ln_y_5] + _b[cons_H_ln_y_1_ln_y_5] + _b[cons_H_ln_y_2_ln_y_5] + _b[cons_H_ln_y_3_ln_y_5] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b = b_y1 + b_y2 + b_y3 + b_y4 + b_y5
bysort company date: gen c_wp = cons_ln_w_p * (_b[cons_y_1_ln_w_p] + _b[cons_y_2_ln_w_p] + _b[cons_y_3_ln_w_p] + _b[cons_y_4_ln_w_p] + _b[cons_y_5_ln_w_p]) 
bysort company date: gen c_wl = cons_ln_w_l * (_b[cons_y_1_ln_w_l] + _b[cons_y_2_ln_w_l] + _b[cons_y_3_ln_w_l] + _b[cons_y_4_ln_w_l] + _b[cons_y_5_ln_w_l]) 
bysort company date: gen c = c_wp + c_wl
bysort company date: gen d = ln_k * (_b[ln_y_1_ln_k] + _b[ln_y_2_ln_k] + _b[ln_y_3_ln_k] + _b[ln_y_4_ln_k] + _b[ln_y_5_ln_k])
bysort company date: gen cf_`model' = 1/(a + b + c + d)
bysort company date: gen dlnCdlnk_`model' = _b[ln_k] + ln_k*_b[H_ln_k_ln_k] + cons_ln_w_p*_b[cons_ln_w_p_ln_k] + cons_ln_w_l*_b[cons_ln_w_l_ln_k] + ln_y_1*_b[ln_y_1_ln_k] + ln_y_2*_b[ln_y_2_ln_k] + ln_y_3*_b[ln_y_3_ln_k] + ln_y_4*_b[ln_y_4_ln_k] + ln_y_5*_b[ln_y_5_ln_k]
bysort company date: gen ec_`model' = (1-dlnCdlnk_`model')/(a + b + c + d)
drop  a-d
}


*******************************************************************
*** 3b: COMPUTING SCALE ECONOMIES FOR EACH BANK
*** TRANSLOG SPECIFICATION
*** MODELLING OF RISK
foreach model of newlist SUR_n_ns {
est restore `model'
bysort company date: gen a_n = _b[ln_y_1] + _b[ln_y_2] + _b[ln_y_3] + _b[ln_y_4] + _b[ln_y_5]
bysort company date: gen b_y1_n = ln_y_1 * (_b[H_ln_y_1_ln_y_1] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_1_ln_y_5])
bysort company date: gen b_y2_n = ln_y_2 * (_b[H_ln_y_2_ln_y_2] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_2_ln_y_5])
bysort company date: gen b_y3_n = ln_y_3 * (_b[H_ln_y_3_ln_y_3] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_3_ln_y_5])
bysort company date: gen b_y4_n = ln_y_4 * (_b[H_ln_y_4_ln_y_4] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b_y5_n = ln_y_5 * (_b[H_ln_y_5_ln_y_5] + _b[cons_H_ln_y_1_ln_y_5] + _b[cons_H_ln_y_2_ln_y_5] + _b[cons_H_ln_y_3_ln_y_5] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b_n = b_y1_n + b_y2_n + b_y3_n + b_y4_n + b_y5_n
bysort company date: gen c_wp_n = cons_ln_w_p * (_b[cons_y_1_ln_w_p] + _b[cons_y_2_ln_w_p] + _b[cons_y_3_ln_w_p] + _b[cons_y_4_ln_w_p] + _b[cons_y_5_ln_w_p]) 
bysort company date: gen c_wl_n = cons_ln_w_l * (_b[cons_y_1_ln_w_l] + _b[cons_y_2_ln_w_l] + _b[cons_y_3_ln_w_l] + _b[cons_y_4_ln_w_l] + _b[cons_y_5_ln_w_l]) 
bysort company date: gen c_n = c_wl_n + c_wp_n
bysort company date: gen d_n = ln_k * (_b[ln_y_1_ln_k] + _b[ln_y_2_ln_k] + _b[ln_y_3_ln_k] + _b[ln_y_4_ln_k] + _b[ln_y_5_ln_k])
bysort company date: gen e_n = ln_n * (_b[ln_y_1_ln_n] + _b[ln_y_2_ln_n] + _b[ln_y_3_ln_n] + _b[ln_y_4_ln_n] + _b[ln_y_5_ln_n])
bysort company date: gen cf_`model' = 1/(a_n + b_n + c_n + d_n + e_n)
bysort company date: gen dlnCdlnk_`model' = _b[ln_k] + ln_k*_b[H_ln_k_ln_k] + cons_ln_w_p*_b[cons_ln_w_p_ln_k] + cons_ln_w_l*_b[cons_ln_w_l_ln_k] + ln_y_1*_b[ln_y_1_ln_k] + ln_y_2*_b[ln_y_2_ln_k] + ln_y_3*_b[ln_y_3_ln_k] + ln_y_4*_b[ln_y_4_ln_k] + ln_y_5*_b[ln_y_5_ln_k] + ln_n*_b[ln_k_ln_n]
bysort company date: gen ec_`model' = (1-dlnCdlnk_`model')/(a_n + b_n + c_n + d_n + e_n)
drop  a_n-e_n
}

*******************************************************************
*** 3c: COMPUTING SCALE ECONOMIES FOR EACH BANK
*** FOURIER FLEXIBLE FUNCTION FORM
*** NO MODELLING OF RISK
sort company date 
xtset company_id date
foreach model of newlist SUR_FF_ns {
est restore `model'
bysort company date: gen a = _b[ln_y_1] + _b[ln_y_2] + _b[ln_y_3] + _b[ln_y_4] + _b[ln_y_5]
bysort company date: gen b_y1 = ln_y_1 * (_b[H_ln_y_1_ln_y_1] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_1_ln_y_5])
bysort company date: gen b_y2 = ln_y_2 * (_b[H_ln_y_2_ln_y_2] + _b[cons_H_ln_y_1_ln_y_2] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_2_ln_y_5])
bysort company date: gen b_y3 = ln_y_3 * (_b[H_ln_y_3_ln_y_3] + _b[cons_H_ln_y_1_ln_y_3] + _b[cons_H_ln_y_2_ln_y_3] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_3_ln_y_5])
bysort company date: gen b_y4 = ln_y_4 * (_b[H_ln_y_4_ln_y_4] + _b[cons_H_ln_y_1_ln_y_4] + _b[cons_H_ln_y_2_ln_y_4] + _b[cons_H_ln_y_3_ln_y_4] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b_y5 = ln_y_5 * (_b[H_ln_y_5_ln_y_5] + _b[cons_H_ln_y_1_ln_y_5] + _b[cons_H_ln_y_2_ln_y_5] + _b[cons_H_ln_y_3_ln_y_5] + _b[cons_H_ln_y_4_ln_y_5])
bysort company date: gen b = b_y1 + b_y2 + b_y3 + b_y4 + b_y5
bysort company date: gen c_wp = cons_ln_w_p * (_b[cons_y_1_ln_w_p] + _b[cons_y_2_ln_w_p] + _b[cons_y_3_ln_w_p] + _b[cons_y_4_ln_w_p] + _b[cons_y_5_ln_w_p]) 
bysort company date: gen c_wl = cons_ln_w_l * (_b[cons_y_1_ln_w_l] + _b[cons_y_2_ln_w_l] + _b[cons_y_3_ln_w_l] + _b[cons_y_4_ln_w_l] + _b[cons_y_5_ln_w_l]) 
bysort company date: gen c = c_wp + c_wl
bysort company date: gen d = ln_k * (_b[ln_y_1_ln_k] + _b[ln_y_2_ln_k] + _b[ln_y_3_ln_k] + _b[ln_y_4_ln_k] + _b[ln_y_5_ln_k])
bysort company date: gen f_q1 = mu1*(-sin_q1*_b[cos_q1] + cos_q1*_b[sin_q1]) + (mu1 + mu1)*(-sin_q11*_b[cos_q11] + cos_q11*_b[sin_q11]) + (mu1 + mu2)*(-sin_q12*_b[cos_q12] + cos_q12*_b[sin_q12]) + (mu1 + mu3)*(-sin_q13*_b[cos_q13] + cos_q13*_b[sin_q13]) + (mu1 + mu4)*(-sin_q14*_b[cos_q14] + cos_q14*_b[sin_q14]) + (mu1 + mu5)*(-sin_q15*_b[cos_q15] + cos_q15*_b[sin_q15])
bysort company date: gen f_q2 = mu2*(-sin_q2*_b[cos_q2] + cos_q2*_b[sin_q2]) + (mu2 + mu2)*(-sin_q22*_b[cos_q22] + cos_q22*_b[sin_q22]) + (mu2 + mu3)*(-sin_q23*_b[cos_q23] + cos_q23*_b[sin_q23]) + (mu2 + mu4)*(-sin_q24*_b[cos_q24] + cos_q24*_b[sin_q24]) + (mu2 + mu5)*(-sin_q25*_b[cos_q25] + cos_q25*_b[sin_q25])
bysort company date: gen f_q3 = mu3*(-sin_q3*_b[cos_q3] + cos_q3*_b[sin_q3]) + (mu3 + mu3)*(-sin_q33*_b[cos_q33] + cos_q33*_b[sin_q33]) + (mu3 + mu3)*(-sin_q34*_b[cos_q34] + cos_q34*_b[sin_q34]) + (mu3 + mu3)*(-sin_q35*_b[cos_q35] + cos_q35*_b[sin_q35])
bysort company date: gen f_q4 = mu4*(-sin_q4*_b[cos_q4] + cos_q4*_b[sin_q4]) + (mu4 + mu4)*(-sin_q44*_b[cos_q44] + cos_q44*_b[sin_q44]) + (mu4 + mu5)*(-sin_q45*_b[cos_q45] + cos_q45*_b[sin_q45])
bysort company date: gen f_q5 = mu5*(-sin_q5*_b[cos_q5] + cos_q5*_b[sin_q5]) + (mu5 + mu5)*(-sin_q55*_b[cos_q55] + cos_q55*_b[sin_q55])
bysort company date: gen f = f_q1 + f_q2 + f_q3 + f_q4 + f_q5
bysort company date: gen cf_`model' = 1/(a + b + c + d + f)
bysort company date: gen dlnCdlnk_`model' = _b[ln_k] + ln_k*_b[H_ln_k_ln_k] + cons_ln_w_p*_b[cons_ln_w_p_ln_k] + cons_ln_w_l*_b[cons_ln_w_l_ln_k] + ln_y_1*_b[ln_y_1_ln_k] + ln_y_2*_b[ln_y_2_ln_k] + ln_y_3*_b[ln_y_3_ln_k] + ln_y_4*_b[ln_y_4_ln_k] + ln_y_5*_b[ln_y_5_ln_k]
bysort company date: gen ec_`model' = (1-dlnCdlnk_`model')/(a + b + c + d + f)
drop  a-f
}
sort order

*******************************************************************
* 4: COMPUTING THE VARIANCE OF SCALE ECONOMIES, DELTA METHOD

*******************************************************************
*** 2a: COMPUTING VARIANCE OF SCALE ECONOMIES FOR EACH BANK 
*** NO RISK TAKING
*** TRANSLOG SPECIFICATION
foreach model of newlist SUR_ns SUR_07_ns SUR_X09_ns {
est restore `model'
matrix V_`model'  = e(V)
matselrc V_`model' Vb_`model', r(1/35) c(1/35)
* matrix list e(V)

sort company date 
xtset company_id date
est restore `model'
bysort company date: gen d_a1  = -(cf_`model')^2
bysort company date: gen d_a2  = -(cf_`model')^2
bysort company date: gen d_a3  = -(cf_`model')^2
bysort company date: gen d_a4  = -(cf_`model')^2
bysort company date: gen d_a5  = -(cf_`model')^2
bysort company date: gen d_a11 = -ln_y_1*(cf_`model')^2
bysort company date: gen d_a22 = -ln_y_2*(cf_`model')^2
bysort company date: gen d_a33 = -ln_y_3*(cf_`model')^2
bysort company date: gen d_a44 = -ln_y_4*(cf_`model')^2
bysort company date: gen d_a55 = -ln_y_5*(cf_`model')^2
bysort company date: gen d_a12 = -(ln_y_1+ln_y_2)*(cf_`model')^2
bysort company date: gen d_a13 = -(ln_y_1+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a14 = -(ln_y_1+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a15 = -(ln_y_1+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a23 = -(ln_y_2+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a24 = -(ln_y_2+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a25 = -(ln_y_2+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a34 = -(ln_y_3+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a35 = -(ln_y_3+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a45 = -(ln_y_4+ln_y_5)*(cf_`model')^2
bysort company date: gen d_np1  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np2  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np3  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np4  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np5  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_nl1  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl2  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl3  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl4  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl5  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_p11  = -ln_k*(cf_`model')^2
bysort company date: gen d_p12  = -ln_k*(cf_`model')^2
bysort company date: gen d_p13  = -ln_k*(cf_`model')^2
bysort company date: gen d_p14  = -ln_k*(cf_`model')^2
bysort company date: gen d_p15  = -ln_k*(cf_`model')^2

sort assetbuckets
foreach var of varlist d_a1-d_p15 {
egen sum00_`var' = sum(`var') if _est_`model' == 1
egen sum11_`var' = sum(`var') if assetbuckets == "1 <$100bn" & _est_`model' == 1
egen sum22_`var' = sum(`var') if assetbuckets == "2 $100bn-$500bn" & _est_`model' == 1
egen sum33_`var' = sum(`var') if assetbuckets == "3 $500bn-$1tn" & _est_`model' == 1
egen sum44_`var' = sum(`var') if assetbuckets == "4 $1tn-$2tn" & _est_`model' == 1
egen sum55_`var' = sum(`var') if assetbuckets == "5 >$2tn" & _est_`model' == 1
}

foreach var of varlist d_a1-d_p15 {
egen sum0_`var' = max(sum00_`var')
}
foreach var of varlist d_a1-d_p15 {
egen sum1_`var' = max(sum11_`var')
}
foreach var of varlist d_a1-d_p15 {
egen sum2_`var' = max(sum22_`var')
}
foreach var of varlist d_a1-d_p15 {
egen sum3_`var' = max(sum33_`var')
}
foreach var of varlist d_a1-d_p15 {
egen sum4_`var' = max(sum44_`var')
}
foreach var of varlist d_a1-d_p15 {
egen sum5_`var' = max(sum55_`var')
}
foreach i of numlist 0/5 {
egen count`i' = count(sum`i'`i'_d_a1) 
}

sort company date
foreach i of numlist 0/5 {
capture mkmat sum`i'_d_a1-sum`i'_d_p15 if company_id == 1 & date == 2001, matrix(gB_`model'_`i')
capture matrix var_`model'_`i' = gB_`model'_`i'*Vb_`model'*gB_`model'_`i''
capture svmat var_`model'_`i', names(temp)
capture replace temp1 = sum(temp)
capture gen se_`model'_`i' = (1/(count`i')^2)*temp1
capture replace se_`model'_`i' = sqrt(se_`model'_`i')
capture drop temp1
}

bysort company date: gen se_mean_cf_`model' = .
capture replace se_mean_cf_`model' = se_`model'_1 if assetbuckets == "1 <$100bn"
capture replace se_mean_cf_`model' = se_`model'_2 if assetbuckets == "2 $100bn-$500bn"
capture replace se_mean_cf_`model' = se_`model'_3 if assetbuckets == "3 $500bn-$1tn"
capture replace se_mean_cf_`model' = se_`model'_4 if assetbuckets == "4 $1tn-$2tn"
capture replace se_mean_cf_`model' = se_`model'_5 if assetbuckets == "5 >$2tn"

drop d_a1-d_p15 sum00_d_a1-count5
* END LOOP
}


*******************************************************************
*** 2b: COMPUTING VARIANCE OF SCALE ECONOMIES FOR EACH BANK 
*** NO RISK TAKING
*** TRANSLOG SPECIFICATION
*** ECONOMIC COST
foreach model of newlist SUR_ns {
est restore `model'
matrix V_`model'  = e(V)
matselrc V_`model' Vb_`model', r(1/35,41/44) c(1/35,41/44)

sort company date 
xtset company_id date
est restore `model'
bysort company date: gen d_a1  = -(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a2  = -(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a3  = -(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a4  = -(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a5  = -(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a11 = -ln_y_1*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a22 = -ln_y_2*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a33 = -ln_y_3*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a44 = -ln_y_4*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a55 = -ln_y_5*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a12 = -(ln_y_1+ln_y_2)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a13 = -(ln_y_1+ln_y_3)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a14 = -(ln_y_1+ln_y_4)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a15 = -(ln_y_1+ln_y_5)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a23 = -(ln_y_2+ln_y_3)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a24 = -(ln_y_2+ln_y_4)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a25 = -(ln_y_2+ln_y_5)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a34 = -(ln_y_3+ln_y_4)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a35 = -(ln_y_3+ln_y_5)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_a45 = -(ln_y_4+ln_y_5)*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_np1 = -cons_ln_w_p*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_np2 = -cons_ln_w_p*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_np3 = -cons_ln_w_p*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_np4 = -cons_ln_w_p*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_np5 = -cons_ln_w_p*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_nl1 = -cons_ln_w_l*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_nl2 = -cons_ln_w_l*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_nl3 = -cons_ln_w_l*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_nl4 = -cons_ln_w_l*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_nl5 = -cons_ln_w_l*(1-dlnCdlnk_`model')*(cf_`model')^2
bysort company date: gen d_p11 = -ln_k*(1-dlnCdlnk_`model')*(cf_`model')^2 - ln_y_1*cf_`model' 
bysort company date: gen d_p12 = -ln_k*(1-dlnCdlnk_`model')*(cf_`model')^2 - ln_y_2*cf_`model' 
bysort company date: gen d_p13 = -ln_k*(1-dlnCdlnk_`model')*(cf_`model')^2 - ln_y_3*cf_`model' 
bysort company date: gen d_p14 = -ln_k*(1-dlnCdlnk_`model')*(cf_`model')^2 - ln_y_4*cf_`model' 
bysort company date: gen d_p15 = -ln_k*(1-dlnCdlnk_`model')*(cf_`model')^2 - ln_y_5*cf_`model' 
bysort company date: gen d_g   = -cf_`model'
bysort company date: gen d_gk  = -ln_k*cf_`model'
bysort company date: gen d_rp  = -cons_ln_w_p*cf_`model'
bysort company date: gen d_rl  = -cons_ln_w_l*cf_`model'

sort assetbuckets
foreach var of varlist d_a1-d_rl {
egen sum00_`var' = sum(`var') if _est_`model' == 1
egen sum11_`var' = sum(`var') if assetbuckets == "1 <$100bn" & _est_`model' == 1
egen sum22_`var' = sum(`var') if assetbuckets == "2 $100bn-$500bn" & _est_`model' == 1
egen sum33_`var' = sum(`var') if assetbuckets == "3 $500bn-$1tn" & _est_`model' == 1
egen sum44_`var' = sum(`var') if assetbuckets == "4 $1tn-$2tn" & _est_`model' == 1
egen sum55_`var' = sum(`var') if assetbuckets == "5 >$2tn" & _est_`model' == 1
}

foreach var of varlist d_a1-d_rl {
egen sum0_`var' = max(sum00_`var')
}
foreach var of varlist d_a1-d_rl {
egen sum1_`var' = max(sum11_`var')
}
foreach var of varlist d_a1-d_rl {
egen sum2_`var' = max(sum22_`var')
}
foreach var of varlist d_a1-d_rl {
egen sum3_`var' = max(sum33_`var')
}
foreach var of varlist d_a1-d_rl {
egen sum4_`var' = max(sum44_`var')
}
foreach var of varlist d_a1-d_rl {
egen sum5_`var' = max(sum55_`var')
}
foreach i of numlist 0/5 {
egen count`i' = count(sum`i'`i'_d_a1) 
}

sort company date
foreach i of numlist 0/5 {
capture mkmat sum`i'_d_a1-sum`i'_d_rl if company_id == 1 & date == 2001, matrix(gB_`model'_`i')
capture matrix var_`model'_`i' = gB_`model'_`i'*Vb_`model'*gB_`model'_`i''
capture svmat var_`model'_`i', names(temp)
capture replace temp1 = sum(temp)
capture gen se_ec_`model'_`i' = (1/(count`i')^2)*temp1
capture replace se_ec_`model'_`i' = sqrt(se_ec_`model'_`i')
capture drop temp1
}

bysort company date: gen se_mean_ec_`model' = .
capture replace se_mean_ec_`model' = se_ec_`model'_1 if assetbuckets == "1 <$100bn"
capture replace se_mean_ec_`model' = se_ec_`model'_2 if assetbuckets == "2 $100bn-$500bn"
capture replace se_mean_ec_`model' = se_ec_`model'_3 if assetbuckets == "3 $500bn-$1tn"
capture replace se_mean_ec_`model' = se_ec_`model'_4 if assetbuckets == "4 $1tn-$2tn"
capture replace se_mean_ec_`model' = se_ec_`model'_5 if assetbuckets == "5 >$2tn"

drop d_a1-d_rl sum00_d_a1-count5
* END LOOP
}

*******************************************************************
*** 2c: COMPUTING VARIANCE OF SCALE ECONOMIES FOR EACH BANK 
*** TRANSLOG SPECIFICATION
*** RISK TAKING
foreach model of newlist SUR_n_ns {
est restore `model'
matrix V_`model'  = e(V)
**** NEED TO ADJUST THIS FOR CORRECT PARAMETERS. POTENTIALLY HOLD OFF UNTIL I HAVE CONFIRMED THE FOURIER FLEXIBLE TRANSFORM
matselrc V_`model' Vb_`model', r(1/40) c(1/40)

sort company date 
xtset company_id date
est restore `model'
bysort company date: gen d_a1  = -(cf_`model')^2
bysort company date: gen d_a2  = -(cf_`model')^2
bysort company date: gen d_a3  = -(cf_`model')^2
bysort company date: gen d_a4  = -(cf_`model')^2
bysort company date: gen d_a5  = -(cf_`model')^2
bysort company date: gen d_a11 = -ln_y_1*(cf_`model')^2
bysort company date: gen d_a22 = -ln_y_2*(cf_`model')^2
bysort company date: gen d_a33 = -ln_y_3*(cf_`model')^2
bysort company date: gen d_a44 = -ln_y_4*(cf_`model')^2
bysort company date: gen d_a55 = -ln_y_5*(cf_`model')^2
bysort company date: gen d_a12 = -(ln_y_1+ln_y_2)*(cf_`model')^2
bysort company date: gen d_a13 = -(ln_y_1+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a14 = -(ln_y_1+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a15 = -(ln_y_1+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a23 = -(ln_y_2+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a24 = -(ln_y_2+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a25 = -(ln_y_2+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a34 = -(ln_y_3+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a35 = -(ln_y_3+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a45 = -(ln_y_4+ln_y_5)*(cf_`model')^2
bysort company date: gen d_np1  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np2  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np3  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np4  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np5  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_nl1  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl2  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl3  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl4  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl5  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_p11  = -ln_k*(cf_`model')^2
bysort company date: gen d_p12  = -ln_k*(cf_`model')^2
bysort company date: gen d_p13  = -ln_k*(cf_`model')^2
bysort company date: gen d_p14  = -ln_k*(cf_`model')^2
bysort company date: gen d_p15  = -ln_k*(cf_`model')^2
bysort company date: gen d_p31  = -ln_n*(cf_`model')^2
bysort company date: gen d_p32  = -ln_n*(cf_`model')^2
bysort company date: gen d_p33  = -ln_n*(cf_`model')^2
bysort company date: gen d_p34  = -ln_n*(cf_`model')^2
bysort company date: gen d_p35  = -ln_n*(cf_`model')^2

sort assetbuckets
foreach var of varlist d_a1-d_p35 {
egen sum00_`var' = sum(`var') if _est_`model' == 1
egen sum11_`var' = sum(`var') if assetbuckets == "1 <$100bn" & _est_`model' == 1
egen sum22_`var' = sum(`var') if assetbuckets == "2 $100bn-$500bn" & _est_`model' == 1
egen sum33_`var' = sum(`var') if assetbuckets == "3 $500bn-$1tn" & _est_`model' == 1
egen sum44_`var' = sum(`var') if assetbuckets == "4 $1tn-$2tn" & _est_`model' == 1
egen sum55_`var' = sum(`var') if assetbuckets == "5 >$2tn" & _est_`model' == 1
}

foreach var of varlist d_a1-d_p35 {
egen sum0_`var' = max(sum00_`var')
}
foreach var of varlist d_a1-d_p35 {
egen sum1_`var' = max(sum11_`var')
}
foreach var of varlist d_a1-d_p35 {
egen sum2_`var' = max(sum22_`var')
}
foreach var of varlist d_a1-d_p35 {
egen sum3_`var' = max(sum33_`var')
}
foreach var of varlist d_a1-d_p35 {
egen sum4_`var' = max(sum44_`var')
}
foreach var of varlist d_a1-d_p35 {
egen sum5_`var' = max(sum55_`var')
}
foreach i of numlist 0/5 {
egen count`i' = count(sum`i'`i'_d_a1) 
}

sort company date
foreach i of numlist 0/5 {
capture mkmat sum`i'_d_a1-sum`i'_d_p35 if company_id == 1 & date == 2001, matrix(gB_`model'_`i')
capture matrix var_`model'_`i' = gB_`model'_`i'*Vb_`model'*gB_`model'_`i''
capture svmat var_`model'_`i', names(temp)
capture replace temp1 = sum(temp)
capture gen se_`model'_`i' = (1/(count`i')^2)*temp1
capture replace se_`model'_`i' = sqrt(se_`model'_`i')
capture drop temp1
}

bysort company date: gen se_mean_cf_`model' = .
capture replace se_mean_cf_`model' = se_`model'_1 if assetbuckets == "1 <$100bn"
capture replace se_mean_cf_`model' = se_`model'_2 if assetbuckets == "2 $100bn-$500bn"
capture replace se_mean_cf_`model' = se_`model'_3 if assetbuckets == "3 $500bn-$1tn"
capture replace se_mean_cf_`model' = se_`model'_4 if assetbuckets == "4 $1tn-$2tn"
capture replace se_mean_cf_`model' = se_`model'_5 if assetbuckets == "5 >$2tn"


drop d_a1-d_p35 sum00_d_a1-count5
* END LOOP
}

*******************************************************************
*** 2d: COMPUTING VARIANCE OF SCALE ECONOMIES FOR EACH BANK 
*** NO RISK TAKING
*** FOURIER SPECIFICATION
foreach model of newlist SUR_FF_ns {
est restore `model'
matrix V_`model'  = e(V)
matselrc V_`model' Vb_`model', r(1/35,45/84) c(1/35,45/84)

sort company date 
xtset company_id date
est restore `model'
bysort company date: gen d_a1  = -(cf_`model')^2
bysort company date: gen d_a2  = -(cf_`model')^2
bysort company date: gen d_a3  = -(cf_`model')^2
bysort company date: gen d_a4  = -(cf_`model')^2
bysort company date: gen d_a5  = -(cf_`model')^2
bysort company date: gen d_a11 = -ln_y_1*(cf_`model')^2
bysort company date: gen d_a22 = -ln_y_2*(cf_`model')^2
bysort company date: gen d_a33 = -ln_y_3*(cf_`model')^2
bysort company date: gen d_a44 = -ln_y_4*(cf_`model')^2
bysort company date: gen d_a55 = -ln_y_5*(cf_`model')^2
bysort company date: gen d_a12 = -(ln_y_1+ln_y_2)*(cf_`model')^2
bysort company date: gen d_a13 = -(ln_y_1+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a14 = -(ln_y_1+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a15 = -(ln_y_1+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a23 = -(ln_y_2+ln_y_3)*(cf_`model')^2
bysort company date: gen d_a24 = -(ln_y_2+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a25 = -(ln_y_2+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a34 = -(ln_y_3+ln_y_4)*(cf_`model')^2
bysort company date: gen d_a35 = -(ln_y_3+ln_y_5)*(cf_`model')^2
bysort company date: gen d_a45 = -(ln_y_4+ln_y_5)*(cf_`model')^2
bysort company date: gen d_np1  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np2  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np3  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np4  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_np5  = -cons_ln_w_p*(cf_`model')^2
bysort company date: gen d_nl1  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl2  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl3  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl4  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_nl5  = -cons_ln_w_l*(cf_`model')^2
bysort company date: gen d_p11  = -ln_k*(cf_`model')^2
bysort company date: gen d_p12  = -ln_k*(cf_`model')^2
bysort company date: gen d_p13  = -ln_k*(cf_`model')^2
bysort company date: gen d_p14  = -ln_k*(cf_`model')^2
bysort company date: gen d_p15  = -ln_k*(cf_`model')^2

bysort company date: gen d_t1  = mu1*sin_q1*(cf_`model')^2
bysort company date: gen d_w1  = -mu1*cos_q1*(cf_`model')^2
bysort company date: gen d_t11 = 2*mu1*sin_q11*(cf_`model')^2
bysort company date: gen d_w11 = -2*mu1*cos_q11*(cf_`model')^2
bysort company date: gen d_t2  = mu2*sin_q2*(cf_`model')^2
bysort company date: gen d_w2  = -mu2*cos_q2*(cf_`model')^2
bysort company date: gen d_t22 = 2*mu2*sin_q22*(cf_`model')^2
bysort company date: gen d_w22 = -2*mu2*cos_q22*(cf_`model')^2
bysort company date: gen d_t3  = mu3*sin_q3*(cf_`model')^2
bysort company date: gen d_w3  = -mu3*cos_q3*(cf_`model')^2
bysort company date: gen d_t33 = 2*mu3*sin_q33*(cf_`model')^2
bysort company date: gen d_w33 = -2*mu3*cos_q33*(cf_`model')^2
bysort company date: gen d_t4  = mu4*sin_q4*(cf_`model')^2
bysort company date: gen d_w4  = -mu4*cos_q4*(cf_`model')^2
bysort company date: gen d_t44 = 2*mu4*sin_q44*(cf_`model')^2
bysort company date: gen d_w44 = -2*mu4*cos_q44*(cf_`model')^2
bysort company date: gen d_t5  = mu5*sin_q5*(cf_`model')^2
bysort company date: gen d_w5  = -mu5*cos_q5*(cf_`model')^2
bysort company date: gen d_t55 = 2*mu5*sin_q55*(cf_`model')^2
bysort company date: gen d_w55 = -2*mu5*cos_q55*(cf_`model')^2
bysort company date: gen d_t12 = (mu1+mu2)*sin_q12*(cf_`model')^2
bysort company date: gen d_w12 = -(mu1+mu2)*cos_q12*(cf_`model')^2
bysort company date: gen d_t13 = (mu1+mu3)*sin_q13*(cf_`model')^2
bysort company date: gen d_w13 = -(mu1+mu3)*cos_q13*(cf_`model')^2
bysort company date: gen d_t14 = (mu1+mu4)*sin_q14*(cf_`model')^2
bysort company date: gen d_w14 = -(mu1+mu4)*cos_q14*(cf_`model')^2
bysort company date: gen d_t15 = (mu1+mu5)*sin_q15*(cf_`model')^2
bysort company date: gen d_w15 = -(mu1+mu5)*cos_q15*(cf_`model')^2
bysort company date: gen d_t23 = (mu2+mu3)*sin_q23*(cf_`model')^2
bysort company date: gen d_w23 = -(mu2+mu3)*cos_q23*(cf_`model')^2
bysort company date: gen d_t24 = (mu2+mu4)*sin_q24*(cf_`model')^2
bysort company date: gen d_w24 = -(mu2+mu4)*cos_q24*(cf_`model')^2
bysort company date: gen d_t25 = (mu2+mu5)*sin_q25*(cf_`model')^2
bysort company date: gen d_w25 = -(mu2+mu5)*cos_q25*(cf_`model')^2
bysort company date: gen d_t34 = (mu3+mu4)*sin_q34*(cf_`model')^2
bysort company date: gen d_w34 = -(mu3+mu4)*cos_q34*(cf_`model')^2
bysort company date: gen d_t35 = (mu3+mu5)*sin_q35*(cf_`model')^2
bysort company date: gen d_w35 = -(mu3+mu5)*cos_q35*(cf_`model')^2
bysort company date: gen d_t45 = (mu4+mu5)*sin_q45*(cf_`model')^2
bysort company date: gen d_w45 = -(mu4+mu5)*cos_q45*(cf_`model')^2

sort assetbuckets
foreach var of varlist d_a1-d_w45 {
egen sum00_`var' = sum(`var') if _est_`model' == 1
egen sum11_`var' = sum(`var') if assetbuckets == "1 <$100bn" & _est_`model' == 1
egen sum22_`var' = sum(`var') if assetbuckets == "2 $100bn-$500bn" & _est_`model' == 1
egen sum33_`var' = sum(`var') if assetbuckets == "3 $500bn-$1tn" & _est_`model' == 1
egen sum44_`var' = sum(`var') if assetbuckets == "4 $1tn-$2tn" & _est_`model' == 1
egen sum55_`var' = sum(`var') if assetbuckets == "5 >$2tn" & _est_`model' == 1
}

foreach var of varlist d_a1-d_w45 {
egen sum0_`var' = max(sum00_`var')
}
foreach var of varlist d_a1-d_w45 {
egen sum1_`var' = max(sum11_`var')
}
foreach var of varlist d_a1-d_w45 {
egen sum2_`var' = max(sum22_`var')
}
foreach var of varlist d_a1-d_w45 {
egen sum3_`var' = max(sum33_`var')
}
foreach var of varlist d_a1-d_w45 {
egen sum4_`var' = max(sum44_`var')
}
foreach var of varlist d_a1-d_w45 {
egen sum5_`var' = max(sum55_`var')
}
foreach i of numlist 0/5 {
egen count`i' = count(sum`i'`i'_d_a1) 
}

sort company date
foreach i of numlist 0/5 {
capture mkmat sum`i'_d_a1-sum`i'_d_w45 if company_id == 1 & date == 2001, matrix(gB_`model'_`i')
capture matrix var_`model'_`i' = gB_`model'_`i'*Vb_`model'*gB_`model'_`i''
capture svmat var_`model'_`i', names(temp)
capture replace temp1 = sum(temp)
capture gen se_`model'_`i' = (1/(count`i')^2)*temp1
capture replace se_`model'_`i' = sqrt(se_`model'_`i')
capture drop temp1
}

bysort company date: gen se_mean_cf_`model' = .
capture replace se_mean_cf_`model' = se_`model'_1 if assetbuckets == "1 <$100bn"
capture replace se_mean_cf_`model' = se_`model'_2 if assetbuckets == "2 $100bn-$500bn"
capture replace se_mean_cf_`model' = se_`model'_3 if assetbuckets == "3 $500bn-$1tn"
capture replace se_mean_cf_`model' = se_`model'_4 if assetbuckets == "4 $1tn-$2tn"
capture replace se_mean_cf_`model' = se_`model'_5 if assetbuckets == "5 >$2tn"

drop d_a1-d_w45 sum00_d_a1-count5
* END LOOP
}


*** SUMMARY STATISTICS OF SCALE ECONOMIES ESTIMATES -- no TBTF in prodn technology
foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}
foreach model of newlist SUR {
table assetbuckets if date > 2000 & _est_`model' == 1, c(count ec_`model'_ns mean ec_`model'_ns mean se_mean_ec_`model'_ns)
}
foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
table _est_`model' if date > 2000 & _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table _est_`model' if date > 2000 & _est_`model'==1, c(count ec_`model'_ns mean ec_`model'_ns mean se_ec_`model'_ns_0)
}

foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
table assetbuckets implicit_subsidy if date > 2000 & _est_`model' == 1, c(count cf_`model'_ns mean cf_`model'_ns mean se_mean_cf_`model'_ns)
}
foreach model of newlist SUR {
table assetbuckets implicit_subsidy if date > 2000 & _est_`model' == 1, c(count ec_`model'_ns mean ec_`model'_ns mean se_mean_ec_`model'_ns)
}
foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
table _est_`model' implicit_subsidy if _est_`model'==1, c(count cf_`model'_ns mean cf_`model'_ns mean se_`model'_ns_0)
}
foreach model of newlist SUR {
table _est_`model' implicit_subsidy if _est_`model'==1, c(count ec_`model'_ns mean ec_`model'_ns mean se_ec_`model'_ns_0)
}

sort order
