*******************************************************************
* PROGRAMME: SCALE ECONOMIES MERGER FILE
*******************************************************************

*******************************************************************
*** IMPORTANT NOTATION POINT
* Here, 'nosubsidy' actually means: no subsidy adjustment made
* And 'subsidy means: adjusting for the subsidy

*******************************************************************
*** IMPORT DATA
clear
set more off
* cd to put in relevant directory here
use "Scale_economies_3input_nosubsidy.dta"

foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
rename cf_`model' cf_`model'_nosubsidy
}

foreach model of newlist SUR {
rename ec_`model' ec_`model'_nosubsidy
}

foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
rename se_mean_cf_`model' se_mean_cf_`model'_nosubsidy
}

foreach model of newlist SUR {
rename se_mean_ec_`model' se_mean_ec_`model'_nosubsidy
}

save "Scale_economies_3input_nosubsidy_base.dta", replace

clear
set more off
* cd to put in relevant directory here
use "Scale_economies_3input_subsidy.dta"

foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
rename cf_`model' cf_`model'_subsidy
}

foreach model of newlist SUR {
rename ec_`model' ec_`model'_subsidy
}

foreach model of newlist SUR SUR_07 SUR_X09 SUR_n SUR_FF {
rename se_mean_cf_`model' se_mean_cf_`model'_subsidy
}

foreach model of newlist SUR {
rename se_mean_ec_`model' se_mean_ec_`model'_subsidy
}

save "Scale_economies_3input_subsidy_base.dta", replace

clear
set more off
* cd to put in relevant directory here
use "Scale_economies_3input_nosubsidy_base.dta"

joinby company date using "Scale_economies_3input_subsidy_base.dta", unmatched(master)
drop _merge

keep order-date total_assets int_exp_total total_deposits st_debt_bnk lt_debt_bnk implicit_subsidy implicit_subsidy2 implicit_subsidy4 total_cost w_d w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration assetbuckets cf_SUR_nosubsidy- se_mean_cf_SUR_FF_nosubsidy cf_SUR_subsidy- se_mean_cf_SUR_FF_subsidy

*******************************************************************
*** REGION VARIABLE (used for summary statistics)
gen region2 = "ROW"
replace region2 = "Asia and Oceania" if country == "Australia"
replace region2 = "Europe" if country == "Austria"
replace region2 = "Europe" if country == "Belgium"
replace region2 = "Americas" if country == "Brazil"
replace region2 = "Americas" if country == "Canada"
replace region2 = "Asia and Oceania" if country == "China"
replace region2 = "Europe" if country == "Cyprus"
replace region2 = "Europe" if country == "Denmark"
replace region2 = "Europe" if country == "France"
replace region2 = "Europe" if country == "Germany"
replace region2 = "Europe" if country == "Greece"
replace region2 = "Asia and Oceania" if country == "Hong Kong"
replace region2 = "Asia and Oceania" if country == "India"
replace region2 = "Europe" if country == "Ireland"
replace region2 = "Middle East and Africa" if country == "Israel"
replace region2 = "Europe" if country == "Italy"
replace region2 = "Asia and Oceania" if country == "Japan"
replace region2 = "Middle East and Africa" if country == "Jordan"
replace region2 = "Europe" if country == "Luxembourg"
replace region2 = "Asia and Oceania" if country == "Malaysia"
replace region2 = "Europe" if country == "Netherlands"
replace region2 = "Europe" if country == "Norway"
replace region2 = "Europe" if country == "Poland"
replace region2 = "Europe" if country == "Portugal"
replace region2 = "Middle East and Africa" if country == "Qatar"
replace region2 = "Europe" if country == "Russia"
replace region2 = "Asia and Oceania" if country == "Singapore"
replace region2 = "Middle East and Africa" if country == "South Africa"
replace region2 = "Asia and Oceania" if country == "South Korea"
replace region2 = "Europe" if country == "Spain"
replace region2 = "Europe" if country == "Sweden"
replace region2 = "Europe" if country == "Switzerland"
replace region2 = "Asia and Oceania" if country == "Taiwan"
replace region2 = "Asia and Oceania" if country == "Thailand"
replace region2 = "Middle East and Africa" if country == "Turkey"
replace region2 = "Europe" if country == "United Kingdom"
replace region2 = "Americas" if country == "United States"

*******************************************************************
*** GENERATING W_D VARIABLES
replace w_d = int_exp_total/(total_deposits + st_debt_bnk + lt_debt_bnk)
replace w_d = w_d*100
gen w_d_star = (int_exp_total+implicit_subsidy4)/(total_deposits + st_debt_bnk + lt_debt_bnk)
replace w_d_star = w_d_star*100
replace w_l = w_l*100
replace w_p = w_p*100
 
*******************************************************************
*** SUMMARY STATISTICS FOR TABLE B.2 and TABLE B.3: MEAN AND STD DEV, 2001-2010
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table _est_SUR if date > 2000, c(mean `var' sd `var')
}
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table region2 if date > 2000 & _est_SUR == 1, c(mean `var' sd `var')
}
foreach var of varlist total_cost w_d w_d_star w_l w_p y_1- y_5 k n gdp_growth_real interest_rates gdp_pc credit_gdp_ratio bank_sys_concentration {
table assetbuckets if date > 2000 & _est_SUR == 1, c(mean `var' sd `var')
}

*******************************************************************
*** RATIOS FOR IMPLICIT SUBSIDY STATISTICS
*** Ratio of the subsidy to total assets
gen subsidy_assets_ratio = implicit_subsidy4/total_assets
replace subsidy_assets_ratio = subsidy_assets_ratio*100
*** Proportion of other funding, other than deposits (ratio of non-deposit funding to total funding - per cent)
gen other_funding = (st_debt_bnk + lt_debt_bnk)/(total_deposits + st_debt_bnk + lt_debt_bnk)
replace other_funding = other_funding*100
*** Raw difference in interest expense, i.e. the funding cost reduction due to the implicit subsidy
gen funding_cost_reduction = implicit_subsidy4/(int_exp_total + implicit_subsidy4)
replace funding_cost_reduction = funding_cost_reduction*100

*******************************************************************
*** SUMMARY STATISTICS FOR TABLE 1: THE IMPACT OF THE IMPLICIY SUBSIDY ON THE PRICE OF DEBT
*** SUMMARY STATISTICS FOR TABLE 2: CHARACTERISTICS OF THE IMPLICIT SUBSIDY

table _est_SUR if date > 2000, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table assetbuckets if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table region2      if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)
table date         if date > 2000 & _est_SUR == 1, c(count w_d mean w_d mean w_d_star) by(implicit_subsidy)

table implicit_subsidy if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction)
table region2      if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)
table assetbuckets if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)
table date if date > 2000 & _est_SUR == 1, c(count implicit_subsidy2 mean subsidy_assets_ratio mean implicit_subsidy2 mean other_funding mean funding_cost_reduction) by(implicit_subsidy)

save "Scale_economies_investigation.dta", replace
