*******************************************************************
* PROGRAMME: CROSS ELASTICITIES
*******************************************************************

*******************************************************************
*** COMPUTING OWN AND CROSS PRICE ELASTICITIES AT MEAN VALUES

egen S_d_avg = mean(S_d) if _est_SUR == 1
egen S_l_avg = mean(S_l) if _est_SUR == 1
egen S_p_avg = mean(S_p) if _est_SUR == 1

replace w_d = int_exp_total/(total_deposits + st_debt_bnk + lt_debt_bnk)
gen w_d_star = (int_exp_total + implicit_subsidy4)/(total_deposits + st_debt_bnk + lt_debt_bnk)
egen w_d_avg = mean(w_d) if _est_SUR == 1
egen w_d_star_avg = mean(w_d_star) if _est_SUR == 1
egen w_l_avg = mean(w_l) if _est_SUR == 1
egen w_p_avg = mean(w_p) if _est_SUR == 1

egen total_assets_avg = mean(total_assets) if _est_SUR == 1
egen debt_avg = mean(total_deposits + st_debt_bnk + lt_debt_bnk) if _est_SUR == 1

*******************************************************************
*** 3: COMPUTING OWN AND CROSS PRICE ELASTICITIES

est restore SUR
gen B_pp = _b[cons_H_ln_w_p_ln_w_p]
gen B_ll = _b[cons_H_ln_w_l_ln_w_l]
gen B_pl = _b[cons_H_ln_w_p_ln_w_l]

gen B_dd = B_ll + B_pp + 2*B_pl
gen B_dp = - B_pp - B_pl
gen B_dl = - B_ll - B_pl

* Own-price elasticity for demand of debt with respect to a price change in debt
gen G_dd = B_dd/S_d_avg + S_d_avg - 1

* Cross-price elasticities of demand for labour with respect to a price change in debt
gen G_ld = B_dl/S_l_avg + S_d_avg

* Cross-price elasticities of demand for physical capital with respect to a price change in debt
gen G_pd = B_dp/S_p_avg + S_d_avg

* Impact of a 1% increase in the price of debt
table _est_SUR if date > 2000 & _est_SUR == 1, c(count G_dd mean G_ld mean G_pd mean G_dd )
table assetbuckets if date > 2000 & _est_SUR == 1, c(count G_dd mean G_ld mean G_pd mean G_dd )

* Estimate of change in the price of debt due to the implicit subsidy
gen Delta_w_d = ((w_d_star_avg-w_d_avg)/w_d_avg)*100 if _est_SUR == 1

gen Delta_w_d_check = ((w_d_star_avg-w_d_avg)/w_d_avg) if _est_SUR == 1

table _est_SUR, c(mean Delta_w_d)
table _est_SUR, c(mean Delta_w_d_check)

*******************************************************************
*** 4: IMPACT OF IMPLICITY SUBSIDY ON OWN AND CROSS PRICE ELASTICITIES
* Estimated impact of the change in the price of debt due to the implicit subsidy: 
* a rough estimate of the extent to which the input vector would have changed if 
* banks were faced with the counterfactual estimate of the social price of debt

* Own-price elasticity for demand of debt with respect to a price change in debt
gen G_dd_subsidy = Delta_w_d*G_dd if _est_SUR == 1

* Cross-price elasticities of demand for labour with respect to a price change in debt
gen G_ld_subsidy = Delta_w_d*G_ld if _est_SUR == 1

* Cross-price elasticities of demand for physical capital with respect to a price change in debt
gen G_pd_subsidy = Delta_w_d*G_pd if _est_SUR == 1

table _est_SUR if date > 2000 & _est_SUR == 1, c(count G_dd_subsidy mean G_ld_subsidy mean G_pd_subsidy mean G_dd_subsidy)

*******************************************************************
*** 5: IMPACT OF IMPLICITY SUBSIDY ON OWN AND CROSS PRICE ELASTICITIES
* Estimate total costs, based the original input vector combined with the new price. 
* vector that includes the social price of debt. 
* We estimate that there is about a 0.3 per cent difference between these two estimates of total costs.

gen l_adj = total_assets_avg*(1 + G_ld_subsidy/100) if _est_SUR == 1
gen p_adj = total_assets_avg*(1 + G_pd_subsidy/100) if _est_SUR == 1
gen d_adj = debt_avg*(1 + G_dd_subsidy/100) if _est_SUR == 1
gen total_cost_adj = w_p_avg*p_adj + w_l_avg*l_adj + w_d_star_avg*d_adj if _est_SUR == 1
gen total_cost_sub = w_p_avg*total_assets_avg + w_l_avg*total_assets_avg + w_d_star_avg*debt_avg if _est_SUR == 1
gen total_cost_delta = ((total_cost_sub-total_cost_adj)/total_cost_sub)*100 if _est_SUR == 1

table _est_SUR if date > 2000 & _est_SUR == 1, c(count total_cost_delta mean total_cost_delta)

table _est_SUR if date > 2000 & _est_SUR == 1, c(count G_dd_subsidy mean G_ld_subsidy mean G_pd_subsidy mean G_dd_subsidy)
table _est_SUR if date > 2000 & _est_SUR == 1, c(count total_cost_delta mean total_cost_delta)

